import {
        geoPath, 
        geoNaturalEarth1,
        zoom, 
        event,
} from 'd3';

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

export const choroplethMap = (selection, props) => {
	const {
    svg,
    features,
    colorScale,
    colorValue,
    selectedColorValue
  } = props;
  
  const gUpdate = selection.selectAll('g').data([null]);
  const gEnter = gUpdate.enter().append('g');
  const g = gUpdate.merge(gEnter);
  
	gEnter.append('path')
    	.attr('class', 'sphere')
    	.attr('d', pathGenerator({type: 'Sphere'}))
		.merge(gUpdate.select('.sphere'))
  		.attr('opacity', selectedColorValue ? 0.2 : 1);
  
  svg.call(zoom().on('zoom', () => {
    g.attr('transform', event.transform)
  }));
  
  const countryPaths = g.selectAll('.country').data(features);
  const countryPathsEnter = countryPaths
  	.enter().append('path')
  		.attr('class', 'country');
  countryPaths
  	.merge(countryPathsEnter)
  		.attr('d', pathGenerator)
  		.attr('fill', d => colorScale(colorValue(d)))
  		.attr('opacity', d => (selectedColorValue === colorValue(d) || !selectedColorValue) ? 1 : 0.2)
  		.classed('highlighted-country', d => (selectedColorValue && selectedColorValue === colorValue(d)) ? true : false);
  countryPathsEnter
  	.append('title')
  		.text(d => d.properties.name + ': ' + d.properties.economy);
}