export const colorLegend = (selection, props ) => {
  const { colorScale, circleRadius, spacing, textOffset, onClick, selectedColorValue } = props;

  const backgroundRect = selection.selectAll('rect')
  	.data([null]);
  const n = colorScale.domain().length;
  const longestName = colorScale.domain().reduce((a,b) => { 
    return a.length > b.length ? a : b; 
  }, '').length;
  backgroundRect.enter().append('rect')
  	.merge(backgroundRect)
  		.attr('x', -circleRadius * 2)
  		.attr('y', -circleRadius * 2)
  		.attr('width', `${longestName * (2/3)}em`)
  		.attr('height', spacing * n + circleRadius)
  		.attr('rx', circleRadius)
  		.attr('fill', 'white')
  		.attr('opacity', 0.5);
  const groups = selection.selectAll('.tick').data(colorScale.domain());
  const groupsEnter = groups.enter().append('g').attr('class', 'tick');
  
  groupsEnter.merge(groups)
  	.attr('transform', (d, i) => `translate(0, ${i * spacing})`)
  	.attr('opacity', d =>
  	(!selectedColorValue || d === selectedColorValue)
  	? 1 
  	: 0.3
  	)
  	.on('click', d => onClick(
  	d === selectedColorValue
    ? null
    : d
  ))
  groups.exit().remove();
  
  groupsEnter
    .append('circle')
    .merge( groups.select('circle'))
      .attr('fill', colorScale)
      .attr('r', circleRadius)
  
	groupsEnter.append('text')
    .merge(groups.select('text'))
  		.text(d => d)
  		.attr('x', textOffset)
  		.attr('dy', '0.32em');
  
}